clear; close all; clc

%% Generate signals
ts = linspace(0,20,1000);
t = 1:20;
[Ts,T] = ndgrid(ts,t);

signal(:,1) = sin(ts)';
signal(:,2) = sin(ts-1)';
signal(:,3) = sinc(Ts-T)*randn(size(t))';

%% Extract Hilbert phase
phase = angle(hilbert(signal)); % extract phase for each column

%% plot signals, their phases, and histogram of phase differences
comb = [1,1;1,2;1,3]; % combinations between channels for illustration
figure('Position',[30,60,900,500],'Color',[1 1 1]);
for i = 1:3
    subplot(3,3,i);
    plot(ts,signal(:,comb(i,1)),ts,signal(:,comb(i,2)),'--','linewidth',2);
    box off; axis tight; xlabel Time; ylabel Signal; set(gca,'fontsize',12)
    
    subplot(3,3,i+3);
    plot(ts,phase(:,comb(i,1)),ts,phase(:,comb(i,2)),'--','linewidth',2);
    box off; axis tight; xlabel Time; ylabel 'Phase (rad)'; set(gca,'fontsize',12)
    
    subplot(3,3,i+6);
    h = rose(phase(:,comb(i,1))-phase(:,comb(i,2)));
    set(h,'linewidth',2)
    
    % Calculate Mean Phase Coherence (MPC)
    MPC(i) = abs(mean(exp(1i*(phase(:,comb(i,1))-phase(:,comb(i,2))))));
    xlabel(['MPC = ' num2str(MPC(i))])
end
