clear; close all; clc

load('data_MPC')


% Instantaneous phase for different freq. bands
winLen = 4;  % length of moving window in second
stepLen = 0.5; % step of moving window in second
freqBands = [0.5 45; 0.5 4; 4 8; 8 12; 12 18; 18 30; 30 47; 53 70; 70 97];

figure('Position',[30,60,900,400],'Color',[1 1 1]); hold on
time = 1/sampRate:1/sampRate:2;
shift = 0;

nSeg = floor(length(signal1)/(stepLen*sampRate))-ceil((winLen-stepLen)/stepLen); % number of segments
MPC = zeros(nSeg, size(freqBands,1)); % preallocation
MPCphase = zeros(nSeg, size(freqBands,1)); % preallocation
for nf = 1:size(freqBands,1) % loop for frequency bands
    
    % filter signals for frequency bands
    order = round(3*(sampRate/freqBands(nf,1)));
    fir1Coef = fir1(order,[freqBands(nf,1),freqBands(nf,2)]./(sampRate/2));
    filtSignal1 = filtfilt(fir1Coef, 1, signal1);
    filtSignal2 = filtfilt(fir1Coef, 1, signal2);
    
    % extract instantaneous phase of signals using hilbert transform
    phase1 = angle(hilbert(filtSignal1));
    phase2 = angle(hilbert(filtSignal2));
    
    plot(time, shift+phase1(10001:10000+2*sampRate), time, shift+phase2(10001:10000+2*sampRate), 'r')
    shift = shift+7;
    
    for i = 1:nSeg % loop for segmentation
        idxSeg = floor((i-1)*stepLen*sampRate+1):...
            floor((i-1)*stepLen*sampRate+winLen*sampRate); % index of segment
        
        MPC(i,nf) = abs(mean(exp(1i*(phase1(idxSeg)-phase2(idxSeg))))); % MPC for each segment
        MPCphase(i,nf) = sin(angle(mean(exp(1i*(phase1(idxSeg)-phase2(idxSeg)))))); % MPC for each segment
    end
end
hold off
axis tight
yTickPos = 0:7:56;
ytick = {'0.5-45';'0.5-4';'4-8';'8-12';'12-18';'18-30';'30-50';'50-70';'70-100'};
set(gca,'fontsize',12,'YTick',yTickPos,'YTickLabel',ytick)
xlabel('Time (sec)');
ylabel('Frequency band (Hz)');


%% Plot raw signals
figure('Position',[30,60,900,400],'Color',[1 1 1]);
time = 1/sampRate:1/sampRate:idxSeg(end)/sampRate;
plot(time,signal1(1:idxSeg(end))); box off; hold on
plot(time,signal2(1:idxSeg(end))+1400); hold off
axis tight
set(gca,'fontsize',12)
xlabel('Time (sec)');


%% Plot MPC measure over time and for different frequency bands
figure('Position',[30,60,900,400],'Color',[1 1 1]);
timeMPC = winLen/2:stepLen:mean(idxSeg)/sampRate;
yTickPos = 1:size(freqBands,1);
ytick = {'0.5-45';'0.5-4';'4-8';'8-12';'12-18';'18-30';'30-50';'50-70';'70-100'};
imagesc(timeMPC, yTickPos, MPC'); box off;
set(gca,'YDir','normal');
% contourf(timeMPC, yTickPos, MPC', 10, 'lines', 'none' ); box off;
set(gca,'fontsize',12,'YTick',yTickPos,'YTickLabel',ytick)
c = colorbar;
c.Label.String = 'Mean Phase Coherence';
ylabel('Frequency band (Hz)');
xlabel('Time (sec)');
vline([180-winLen/2, timeMPC(end)-180+winLen/2],'r')


%% Plot MPC measure over time and for different frequency bands
figure('Position',[30,60,900,400],'Color',[1 1 1]);
timeMPC = winLen/2:stepLen:mean(idxSeg)/sampRate;
yTickPos = 1:size(freqBands,1);
ytick = {'0.5-45';'0.5-4';'4-8';'8-12';'12-18';'18-30';'30-50';'50-70';'70-100'};
imagesc(timeMPC, yTickPos, MPCphase'); box off;
set(gca,'YDir','normal');
% contourf(timeMPC, yTickPos, MPC', 10, 'lines', 'none' ); box off;
set(gca,'fontsize',12,'YTick',yTickPos,'YTickLabel',ytick)
c = colorbar;
c.Label.String = 'Phase';
ylabel('Frequency band (Hz)');
xlabel('Time (sec)');
vline([180-winLen/2, timeMPC(end)-180+winLen/2],'r')


%% Histogram of phase differences in 3 conditions
figure('Position',[30,60,900,400],'Color',[1 1 1]);
clear idx
idxFreq = 3; % index of frequency band

[sortMPC,idxSort] = sort(MPC(:,idxFreq),'ascend');
idx(1) = idxSort(1); % lowest MPC
idx(2) = idxSort(floor(length(idxSort)/2)); % middle MPC
idx(3) = idxSort(end); % highest MPC

% filter signals for the mentioned frequency band above (idxFreq)
order = round(3*(sampRate/freqBands(idxFreq,1)));
fir1Coef = fir1(order,[freqBands(idxFreq,1),freqBands(idxFreq,2)]./(sampRate/2));
filtSignal1 = filtfilt(fir1Coef, 1, signal1);
filtSignal2 = filtfilt(fir1Coef, 1, signal2);
% extract instantaneous phase of signals using hilbert transform
phase1 = angle(hilbert(filtSignal1));
phase2 = angle(hilbert(filtSignal2));

titleText = {'desynchronized','weakly synchronized','strongly synchronized'};
for i = 1:3
    subplot(1,3,i);
    
    idxSel1 = floor((idx(3)-1)*stepLen*sampRate+1):floor((idx(3)-1)*stepLen*sampRate+winLen*sampRate);
    h_fake = rose(phase1(idxSel1)-phase2(idxSel1)); hold on % to set same radius for all plots
    set(h_fake,'Visible','off');
    
    idxSel = floor((idx(i)-1)*stepLen*sampRate+1):floor((idx(i)-1)*stepLen*sampRate+winLen*sampRate);
    h = rose(phase1(idxSel)-phase2(idxSel)); hold off
    set(h,'linewidth',2)
    
    title(titleText{i})
end
