clear; close all; clc

load('data_CFC.mat')

%%
% Define phase/amplitude frequency bands of interest
phaseFreq = [6 9]; % frequency band for phase (Hz)
ampFreq = [55 95]; % frequency band for amplitude (Hz)

% Extract envelope for amplitude frequency band using Hilbert transform
order = round(3*(sampRate/ampFreq(1)));
fir1Coef = fir1(order,[ampFreq(1),ampFreq(2)]./(sampRate/2));
ampSignal = filtfilt(fir1Coef, 1, signal);
Amp = abs(hilbert(ampSignal));

% Extract phase for phase frequency band using Hilbert transform
order = round(3*(sampRate/phaseFreq(1)));
fir1Coef = fir1(order,[phaseFreq(1),phaseFreq(2)]./(sampRate/2));
phaseSignal = filtfilt(fir1Coef, 1, signal);
Phase = angle(hilbert(phaseSignal));

% Plot signals
figure('Position',[30,60,800,500],'Color',[1 1 1]);
time = 1/sampRate:1/sampRate:length(ampSignal)/sampRate;
h(1) = subplot(4,2,[1,2]);
plot(time,ampSignal); hold on
plot(time,Amp, 'r'); hold off
box off
ylabel('envelope upper band');
xlabel('time (s)');
set(gca,'fontsize',10);

h(2) = subplot(4,2,[3,4]);
plot(time,-8+0.04*phaseSignal); hold on
plot(time,Phase,'r'); hold off
box off
ylabel('phase lower band');
xlabel('time (s)');
set(gca,'fontsize',10);

linkaxes(h,'x')

%%
% Dividing phase [0 2*pi] into several equal bins
nBin = 18; % 18 bins, each bin covers 20 degrees
binStart = zeros(1, nBin);
binSize = 2*pi/nBin;
for i = 1:nBin
    binStart(i) = (i-1)*binSize-pi; % start of each bin
end

% Compute Modulation Index
meanAmp = zeros(1,nBin); % Mean power in each phase-bin
for k = 1:nBin
    meanAmp(k) = nanmean(Amp(Phase>=binStart(k) & Phase<(binStart(k)+binSize)));
end
meanAmp = meanAmp./sum(meanAmp); % normalize phase-amplitude histogram
KLdist = meanAmp.*log(nBin.*meanAmp); % Kullback-Leibler distance
KLdist(isnan(KLdist)) = 0;
MI = sum(KLdist)./log(nBin); % Normalize KL distance by log(nBin)

% plot phase-amplitude distribution histogram
h(1) = subplot(4,2,[5,7]);
bar(10:20:360,meanAmp,'k');
box off
xlim([0 360])
title('phase-amplitude histogram');
set(gca,'xtick',0:40:360)
xlabel('phase (degree)')
ylabel('norm. amplitude')
set(gca,'fontsize',10);

h(2) = subplot(4,2,[6,8]);
bar(10:20:360,ones(1,nBin)./nBin,'r');
box off
xlim([0 360])
title('uniform phase-amplitude histogram');
set(gca,'xtick',0:40:360)
xlabel('phase (degree)')
ylabel('norm. amplitude')
set(gca,'fontsize',10);

linkaxes(h,'y')
